@@ -13,15 +13,15 @@
 ##############################################################################
 """Unauthorized Exception View Class
 
-$Id: unauthorized.py 100113 2009-05-18 20:08:41Z icemac $
+$Id: unauthorized.py 107631 2010-01-04 15:17:15Z janwijbrand $
 """
 __docformat__ = 'restructuredtext'
 
 from zope.authentication.interfaces import IAuthentication
 from zope.publisher.browser import BrowserPage
-from zope.app.pagetemplate import namedtemplate
+from zope.browserpage import namedtemplate
 from zope.component import getUtility
-from zope.app.pagetemplate import ViewPageTemplateFile
+from zope.browserpage import ViewPageTemplateFile
 
 class Unauthorized(BrowserPage):
 
